#!/usr/bin/python

# todo: add option for either cat or owner trials

import os
from subprocess import call


def ffconcat(cats, tvp):
# cats is a list of strings ["cat--id"]
# tvp: /path/to/trials/videos/

    for cat in cats:

        vid_list = [
            tvp + cat + '_T2.mp4', tvp + cat + '_T4.mp4', tvp + cat + '_T6.mp4',
            tvp + cat + '_T8.mp4', tvp + cat + '_T10.mp4'
        ]

        cat_txt = cat + '.txt'

        if os.path.exists(cat_txt):
            os.remove(cat_txt)

        file_vids = open(cat_txt, 'a')

        for video in vid_list:
            files_list = 'file ' + video + '\n'
            file_vids.write(files_list)
        file_vids.close()

        cat_sh = cat + '.sh'

        if os.path.exists(cat_sh):
            os.remove(cat_sh)

        file_sh = open(cat_sh, 'a')
        ffmpeg_container = " singularity exec /work/chaselab/malyetama/containers/ffmpeg_3.2-nvidia.sif "
        ffmpeg_command = "#!/bin/bash \n" + ffmpeg_container + "ffmpeg -f concat -safe 0 -i " + cat + ".txt -c copy -y " + tvp + cat + "_cat.mp4"

        file_sh.write(ffmpeg_command)
        file_sh.close()

        os.chmod('./' + cat + '.sh', 0o755)
        call('./' + cat + '.sh', shell=True)



import pandas as pd
from csv import reader


def improve_dlc_output(csv_file, type=None):

    df = pd.read_csv(csv_file)

    df = df.iloc[:, :3]

    n = len(df)

    if type is None:
        print("Please specify type!")

    if type is 'owner':
        time = 1020

    if type is 'cat':
        time = 600

    f = n / time

    indx = []

    for i in range(0, n):
        i = i / f
        indx.append(i)

    result = pd.DataFrame(indx, columns=['time'])

    trials = []


    if type is None:
        print("Please specify type!")


    elif type is "owner":

        for i in indx:
            if i < 300:
                trials.append('No treatment')
            elif 300 < i < 480:
                trials.append('First Saline')
            elif 480 < i < 660:
                trials.append('First Urine')
            elif 660 < i < 840:
                trials.append('Second Saline')
            elif 840 < i <= 1020:
                trials.append('Second Urine')


    elif type is "cat":
            t = 120
            if i < t:
                trials.append('Cat alone (1)')
            elif t < i < t*2:
                trials.append('Cat alone (2)')
            elif t*2 < i < t*3:
                trials.append('Cat alone (3)')
            elif t*3 < i < t*4:
                trials.append('Cat alone (4)')
            elif t*4 < i <= t*5:
                trials.append('Cat alone (5)')

    tl = pd.DataFrame(trials, columns=['trial'])

    result = pd.concat([df, result, tl], axis=1)

    result.to_csv(csv_file.strip('.csv') + '_improved.csv',
                  index=False,
                  sep=',',
                  encoding='utf-8')




"""Object-specific python package to run automated tasks in the Chase Lab."""

from .ffsync import ffsync
from .ffconcat import ffconcat
from .lazytrim import lazytrim
from .improve_dlc_output import improve_dlc_output

from .version import __version__, VERSION
